# tplbuild - Templated reproducible container build tool

*tplbuild* is a wrapper around 
[Dockerfiles](https://docs.docker.com/engine/reference/builder/#format)
to make buildilng container images better. The two main features that inspired
the creaton of *tplbuild* were

- Templating build instructions through [Jinja](https://jinja.palletsprojects.com/)
- Enabling fast and reproducible builds among developers

## Installation

*tplbuild* can be installed through *pip*. This installs both the `tplbuild`
CLI utility and the *tplbuild* Python library.

```sh
pip install tplbuild
```

*tplbuild* is supported and tested on Python 3.8-3.10


## Documentation

Documentation for *tplbuild* can be found
[here](https://tplbuild.readthedocs.io/)

### Examples

Check out the [examples](examples/) folder in this repo for some example of
what can be done with `tplbuild`.

### Demo Video

Additionally, you can find a quick tutorial highlighting key features
[here](https://youtu.be/HDiyABr8Adw)

[![Tplbuild Demo
Video](https://img.youtube.com/vi/HDiyABr8Adw/0.jpg)](https://www.youtube.com/watch?v=HDiyABr8Adw "Tplbuild Demo")


